import React, { useState, useRef } from 'react'
import { useTranslation } from 'react-i18next'

import { Box, Button, Step, StepLabel, Stepper } from '@mui/material'
import Page from 'components/page'


import { useHistory } from 'react-router-dom'
import { RegisterFormData } from './formData'
import StepSummary from './stepSummary'
import StepPersonForm from './stepPersonForm'
import { PersonFormMethods } from './personFormMethods'
import { SummaryFormMethods } from './summaryFormMethods'
import SubmitState from './submitState'


const steps = ['Register', 'Summary']


export default function StepRegistration() {
  const { t } = useTranslation(['common'])
  const [formData, setFormData] = useState<RegisterFormData>({
    first_name: undefined,
    last_name: undefined,
    role_type: undefined,
    role_start: undefined,
    role_end: undefined,
    comment: undefined,
    ou_id: undefined,
    email: undefined,
  })
  const history = useHistory()

  const REGISTER_STEP = 0
  const SUMMARY_STEP = 1
  const [activeStep, setActiveStep] = useState(0)
  const personFormRef = useRef<PersonFormMethods>(null)
  const summaryStepRef = useRef<SummaryFormMethods>(null)
  const [submitState, setSubmitState] = useState(SubmitState.NotSubmitted)

  const handleNext = () => {
    if (activeStep === 0) {
      if (personFormRef.current) {
        personFormRef.current.doSubmit()
      }
    } else {
      setActiveStep((prevActiveStep) => prevActiveStep + 1)
    }
  }

  const registerGuest = () => {
    if (summaryStepRef.current) {
      summaryStepRef.current.doSubmit()
    }
  }

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1)
  }

  const handleForwardFromRegister = (updateFormData: RegisterFormData): void => {
    setFormData(updateFormData)
    setActiveStep((prevActiveStep) => prevActiveStep + 1)
  }

  const handleCancel = () => {
    history.push('/')
  }

  const handleSubmitSuccess = () => {
    setSubmitState(SubmitState.SubmitSuccess)
  }

  const handleSubmitFailure = () => {
    setSubmitState(SubmitState.SubmitFailure)
  }

  return (
    <Page>
      {/* Stepper at top of wizard */}
      <Stepper sx={{ paddingTop: '2rem' }}
               activeStep={activeStep}>
        {/* eslint-disable-next-line @typescript-eslint/no-unused-vars */}
        {steps.map((label, index) => {
          const stepProps = {}
          const labelProps = {}
          return (
            <Step key={label} {...stepProps}>
              <StepLabel {...labelProps}>{label}</StepLabel>
            </Step>
          )
        })}
      </Stepper>

      {/* Current page in wizard */}
      <Box sx={{ width: '100%' }}>
        {activeStep === REGISTER_STEP && (
          <StepPersonForm nextHandler={handleForwardFromRegister} formData={formData}
                          ref={personFormRef} />
        )
        }
        {activeStep === SUMMARY_STEP && (
          <StepSummary formData={formData} onSubmitSuccess={handleSubmitSuccess} onSubmitFailure={handleSubmitFailure}
                       ref={summaryStepRef} />
        )}
      </Box>

      <Box sx={{ display: 'flex', flexDirection: 'row', pt: 2, color: 'primary.main', paddingBottom: '1rem'}}>
        {activeStep === REGISTER_STEP && (
          <Button data-testid='button-next'
                  sx={{ color: 'theme.palette.secondary', mr: 1 }}
                  onClick={handleNext}>
            {t('button.next')}
          </Button>
        )}

        {activeStep === SUMMARY_STEP && (
          <>
            <Button
              onClick={handleBack}
              disabled={submitState === SubmitState.SubmitSuccess}
              sx={{ mr: 1 }}
            >
              {t('button.back')}
            </Button>

            <Button onClick={registerGuest}
                    disabled={submitState === SubmitState.SubmitSuccess}
                    sx={{ mr: 1 }}
            >
              {t('button.save')}
            </Button>
          </>
        )}

        <Button onClick={handleCancel}
                disabled={submitState === SubmitState.SubmitSuccess}
        >
          {t('button.cancel')}
        </Button>
      </Box>

    </Page>
  )
}
